==> SQLAlchemy-i18n-0.7.0.tar.gz: SQLAlchemy-i18n-0.7.0/tests/test_find_translations.py <==
# -*- coding: utf-8 -*-
from decimal import Decimal
from sqlalchemy_i18n import find_translations
from tests import TestCase


class TestFindTranslations(TestCase):
    locales = ['en', 'fi', 'sv']

    def test_with_full_confidence(self):
        article = self.Article()
        article.translations['en'].name = u'Some article'
        article.translations['en'].content = u'Some content'
        article.translations['fi'].name = u'Joku artikkeli'
        article.translations['fi'].content = u'Jotain tekstii'
        self.session.add(article)
        self.session.commit()

        article = self.Article()
        article.translations['en'].name = u'Some article'
        self.session.add(article)
        self.session.commit()
        assert dict(find_translations(article, 'name', 'fi')) == {
            u'Joku artikkeli': Decimal(1.0)
        }

    def test_with_varying_confidence(self):
        article = self.Article()
        article.translations['en'].name = u'Some article'
        article.translations['en'].content = u'Some content'
        article.translations['fi'].name = u'Joku artikkeli'
        article.translations['fi'].content = u'Jotain tekstii'
        self.session.add(article)
        article = self.Article()
        article.translations['en'].name = u'Some article'
        article.translations['en'].content = u'Some content'
        article.translations['fi'].name = u'Joku toinen artikkeli'
        article.translations['fi'].content = u'Jotain muuta tekstii'
        self.session.add(article)

        self.session.commit()

        article = self.Article()
        article.translations['en'].name = u'Some article'
        self.session.add(article)
        self.session.commit()

        assert dict(find_translations(article, 'name', 'fi').all()) == {
            u'Joku artikkeli': Decimal(0.5),
            u'Joku toinen artikkeli': Decimal(0.5)
        }

==> SQLAlchemy-i18n-0.8.4.tar.gz: SQLAlchemy-i18n-0.8.4/tests/test_find_translations.py <==
# -*- coding: utf-8 -*-
from decimal import Decimal
from sqlalchemy_i18n import find_translations
from tests import TestCase


class TestFindTranslations(TestCase):
    locales = ['en', 'fi', 'sv']

    def test_with_full_confidence(self):
        article = self.Article()
        article.translations['en'].name = u'Some article'
        article.translations['en'].content = u'Some content'
        article.translations['fi'].name = u'Joku artikkeli'
        article.translations['fi'].content = u'Jotain tekstii'
        self.session.add(article)
        self.session.commit()

        article = self.Article()
        article.translations['en'].name = u'Some article'
        self.session.add(article)
        self.session.commit()
        assert dict(find_translations(article, 'name', 'fi')) == {
            u'Joku artikkeli': Decimal('1.0')
        }

    def test_with_varying_confidence(self):
        article = self.Article()
        article.translations['en'].name = u'Some article'
        article.translations['en'].content = u'Some content'
        article.translations['fi'].name = u'Joku artikkeli'
        article.translations['fi'].content = u'Jotain tekstii'
        self.session.add(article)
        article = self.Article()
        article.translations['en'].name = u'Some article'
        article.translations['en'].content = u'Some content'
        article.translations['fi'].name = u'Joku toinen artikkeli'
        article.translations['fi'].content = u'Jotain muuta tekstii'
        self.session.add(article)

        self.session.commit()

        article = self.Article()
        article.translations['en'].name = u'Some article'
        self.session.add(article)
        self.session.commit()

        assert dict(find_translations(article, 'name', 'fi').all()) == {
            u'Joku artikkeli': Decimal('0.5'),
            u'Joku toinen artikkeli': Decimal('0.5')
        }
